HITRON HDRC-300S — ekfsm documentation

# HITRON HDRC-300S

## Inventory (Object: inventory)

The inventory provides access to the PSU inventory, such as the vendor, model, serial number, and revision.

Method | Description | Example Value
`vendor()` | Get vendor | `Hitron`
`model()` | Get model | `HDRC300S-110J-D120E(N)`
`serial()` | Get serial number | `23450506`
`revision()` | Get Prevision | `0A`

## Device Temperature (Object: th)

Method | Description | Example Value
`temperature()` | Get the temperature | `-10`

## Main Output (Object: main)

The main object respresent the main output module (+12V) of the PSU.

Method | Description | Example Value
`voltage()` | Get actual output voltage | `12.1`
`current()` | Get actual output current | `2.5`
`status()` | Get diagnostics | `<PsuStatus.OUTPUT_OVERVOLTAGE``|``OUTPUT_OVERCURRENT: 48>`

## Standby Output (Object: sby)

The sby object respresent the secondary output module (+5V) of the PSU.

Method | Description | Example Value
`voltage()` | Get actual output voltage | `5.1`
`current()` | Get actual output current | `0.2`
`status()` | Get diagnostics | `<PsuStatus.OUTPUT_OVERVOLTAGE``|``OUTPUT_OVERCURRENT: 48>`

Warning

The status() methods only work if the debug filesystem is mounted.